SDK_VERSION=`dpkg -s libhildon1 | grep Version | cut -d: -f2`
if test "x$SDK_VERSION" = "x 2.0.6-1"; then
	cp debian/control.diablo debian/control
	cp debian/rules.diablo debian/rules
else
	cp debian/control.fremantle debian/control
	cp debian/rules.fremantle debian/rules
fi
